/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.azurecompute.xml;

import com.google.common.collect.ImmutableList;
import org.jclouds.azurecompute.domain.DataVirtualHardDisk;
import org.jclouds.http.functions.BaseHandlerTest;
import org.testng.annotations.Test;

import java.io.InputStream;
import java.net.URI;
import java.util.List;

import static org.testng.Assert.assertEquals;

@Test(groups = "unit", testName = "ListDataVirtualHardDiskHandlerTest")
public class ListDataVirtualHardDisksHandlerTest extends BaseHandlerTest {

   public void test() {
      InputStream is = getClass().getResourceAsStream("/datavirtualharddisk.xml");
      List<DataVirtualHardDisk> result = factory
              .create(new ListDataVirtualHardDisksHandler(new DataVirtualHardDiskHandler())).parse(is);
      assertEquals(result, expected());
   }

   public static List<DataVirtualHardDisk> expected() {
      return ImmutableList.of(
              DataVirtualHardDisk.create(
                      DataVirtualHardDisk.Caching.READ_ONLY,
                      "testimage1-testimage1-0-20120817095145",
                      10,
                      30,
                      URI.create("http://blobs/disks/neotysss/MSFT__Win2K8R2SP1-ABCD-en-us-30GB.vhd"),
                      "Standard"
              ),
              DataVirtualHardDisk.create(
                      DataVirtualHardDisk.Caching.READ_WRITE,
                      "testimage2-testimage2-0-20120817095145",
                      10,
                      30,
                      URI.create("http://blobs/disks/neotysss/MSFT__Win2K8R2SP1-ABCD-en-us-30GB.vhd"),
                      "Standard"
              )
      );
   }
}
